@@ -63,6 +63,7 @@
 #'
 #' `[testdose.error]`: set the allowed error for the test dose, which per
 #' default should not exceed 10\%. The test dose error is calculated as `Tx_net.error/Tx_net`.
+#' The calculation of the $T_{n}$ error is detailed in [calc_OSLLxTxRatio].
 #'
 #' `[palaeodose.error]`: set the allowed error for the De value, which per
 #' default should not exceed 10\%.
@@ -272,7 +273,7 @@ if(is.list(object)){
 
   ##handle main separately
   if("main"%in% names(list(...))){
-    if(class(list(...)$main) == "list"){
+    if(inherits(list(...)$main, "list")){
       main <- rep(list(...)$main,length = length(object))
 
     }else{
@@ -316,7 +317,7 @@ error.list <- list()
 
 # General Integrity Checks ---------------------------------------------------
   ##MISSING INPUT
-  if(class(object)[1] != "RLum.Analysis")
+  if(!inherits(object, "RLum.Analysis"))
     stop("[analyse_SAR.CWOSL()] Input object is not of type 'RLum.Analysis'!",
          call. = FALSE)
 
@@ -1634,10 +1635,10 @@ error.list <- list()
       ##graphical representation of IR-curve
       temp.IRSL <- suppressWarnings(get_RLum(object, recordType = "IRSL"))
       if(length(temp.IRSL) != 0){
-        if(class(temp.IRSL) == "RLum.Data.Curve"){
+        if(inherits(temp.IRSL, "RLum.Data.Curve")){
           plot_RLum.Data.Curve(temp.IRSL, par.local = FALSE)
 
-        }else if(class(temp.IRSL) == "list"){
+        }else if(inherits(temp.IRSL, "list")){
           plot_RLum.Data.Curve(temp.IRSL[[length(temp.IRSL)]], par.local = FALSE)
           warning(
             "[analyse_SAR.CWOSL()] Multiple IRSL curves detected (IRSL test), show only the last one.",
