@@ -75,7 +75,7 @@
 #' @section Function version: 0.3.0
 #'
 #' @author
-#' Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom)
+#' Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany)
 #'
 #' @seealso [calc_TLLxTxRatio], [plot_GrowthCurve], [RLum.Analysis-class],
 #' [RLum.Results-class], [get_RLum]
@@ -123,7 +123,7 @@ analyse_SAR.TL <- function(
 
 
   # Self-call -----------------------------------------------------------------------------------
-  if(class(object) == "list"){
+  if(inherits(object, "list")){
    if(!all(sapply(object, class) == "RLum.Analysis"))
      stop("[analyse_SAR.TL()] All elements in the input list need to be of class 'RLum.Analysis'!",
           call. = FALSE)
