@@ -1,12 +1,42 @@
-#' Apply fading correction after Lamothe et al., 2003
+#'@title Apply fading correction after Lamothe et al., 2003
 #'
-#' This function applies the fading correction for the prediction of long-term fading as suggested
-#' by Lamothe et al., 2003. The function basically adjusts the Ln/Tn values and fit a new dose-response
+#'@description This function applies the fading correction for the prediction of long-term fading as suggested
+#' by Lamothe et al., 2003. The function basically adjusts the $L_n/T_n$ values and fit a new dose-response
 #' curve using the function [plot_GrowthCurve].
 #'
+#'@details
+#'
+#' **Format of `object` if `data.frame`**
+#'
+#' If `object` is of type [data.frame], all input values most be of type [numeric].
+#' Dose values are excepted in seconds (s) not Gray (Gy). No `NA` values are allowed and
+#' the value for the natural dose (first row) should be `0`. Example for three dose points,
+#' column names are arbitrary:
+#'
+#' ```
+#'  object <- data.frame(
+#'  dose = c(0,25,50),
+#'  LxTx = c(4.2, 2.5, 5.0),
+#'  LxTx_error = c(0.2, 0.1, 0.2))
+#'  ```
+#'
+#'  **Note on the g-value and `tc`**
+#'
+#'  Users new to R and fading measurements are often confused about what to
+#'  enter for `tc` and why it may differ from `tc.g_value`. The `tc` value
+#'  is, by convention (Huntley & Lamothe 2001), the time elapsed between the end of the irradiation and the prompt
+#'  measurement. Usually there is no reason for having a `tc` value different for the equivalent dose measurement
+#'  and the *g*-value measurement, except if different equipment was used.
+#'  However, if, for instance, the *g*-value measurement sequence was analysed
+#'  with the *Analyst* (Duller 2015) and the `'Luminescence` is used to correct for fading,
+#'  there is a high chance that the value returned by the *Analyst* comes normalised to 2-days;
+#'  even the `tc` values of the measurement were identical.
+#'  In such cases, the fading correction cannot be correct until the `tc.g_value` was manually
+#'  set to 2-days (`172800` s) because the function will internally recalculate values
+#'  to an identical `tc` value.
 #'
 #' @param object [RLum.Results-class] [data.frame] (**required**): Input data for applying the
-#' fading correction. Allow are (1) [data.frame] with three columns (dose, LxTx, LxTx error), (2)
+#' fading correction. Allow are (1) [data.frame] with three columns (`dose`, `LxTx`, `LxTx error`; see details), (2)
 #' [RLum.Results-class] object created by the function [analyse_SAR.CWOSL] or [analyse_pIRIRSequence]
 #'
 #' @param dose_rate.envir [numeric] vector of length 2 (**required**): Environmental dose rate in mGy/a
@@ -15,19 +45,21 @@
 #' which is, according to Lamothe et al. (2003) De/t*.
 #'
 #' @param g_value [numeric] vector of length 2 (**required**): g_value in \%/decade *recalculated at the moment*
-#' the equivalent dose was calculated, i.e. tc is either similar for the g-value measurement **and** the De measurement or
+#' the equivalent dose was calculated, i.e. `tc` is either similar for the *g*-value measurement **and** the De measurement or
 #' needs be to recalculated (cf. [calc_FadingCorr]). Inserting a normalised g-value, e.g., normalised to 2-days , will
 #' lead to wrong results
 #'
-#' @param tc [numeric] (optional): time in seconds between irradiation and
-#' the prompt measurement used in the De estimation (cf. Huntley & Lamothe 2001).
-#' If set to `NULL` it is assumed that tc is similar for the equivalent dose
-#' estimation and the g-value estimation
+#' @param tc [numeric] (optional): time in seconds between the **end** of the irradiation and
+#' the prompt measurement used in the equivalent dose estimation (cf. Huntley & Lamothe 2001).
+#' If set to `NULL` it is assumed that `tc` is similar for the equivalent dose
+#' estimation and the *g*-value estimation
 #'
-#' @param tc.g_value [numeric] (with default): the time in seconds between irradiation and the prompt measurement used for estimating the g-value.
-#' If the g-value was normalised to, e.g., 2 days, this time in seconds (i.e., 172800) should be given here along with the time used for the
-#' De estimation. If nothing is provided the time is set to tc, which is usual case for g-values obtained using the
-#' SAR method and g-values that had been not normalised to 2 days. Note: If this value is not `NULL` the functions expects a [numeric] value for `tc`.
+#' @param tc.g_value [numeric] (with default): the time in seconds between irradiation and the
+#' prompt measurement estimating the *g*-value. If the *g*-value was normalised to, e.g., 2 days,
+#' this time in seconds (i.e., `172800`) should be entered here along with the time used for the
+#' equivalent dose estimation. If nothing is provided the time is set to `tc`, which is the
+#' usual case for *g*-values obtained using the SAR method and *g*-values that had been not normalised to 2 days.
+#' Note: If this value is not `NULL` the functions expects a [numeric] value for `tc`.
 #'
 #' @param plot [logical] (with default): Enables/disables plot output
 #'
@@ -61,13 +93,16 @@
 #' Huntley, D.J., Lamothe, M., 2001. Ubiquity of anomalous fading in K-feldspars and the measurement
 #' and correction for it in optical dating. Canadian Journal of Earth Sciences 38, 1093-1106.
 #'
+#' Duller, G.A.T., 2015. The Analyst software package for luminescence data: overview and recent improvements.
+#' Ancient TL 33, 35–42.
+#'
 #' Lamothe, M., Auclair, M., Hamzaoui, C., Huot, S., 2003.
 #' Towards a prediction of long-term anomalous fading of feldspar IRSL. Radiation Measurements 37,
 #' 493-498.
 #'
 #' @section Function version: 0.1.0
 #'
-#' @author Sebastian Kreutzer, Geography & Earth Sciences, Aberystwyth University (United Kingdom), Norbert Mercier,
+#' @author Sebastian Kreutzer, Institute of Geography, Heidelberg University (Germany), Norbert Mercier,
 #' IRAMAT-CRP2A, Université Bordeaux Montaigne (France)
 #'
 #' @keywords datagen
@@ -143,7 +178,7 @@ calc_Lamothe2003 <- function(
 
   ##check input type and length
   ##dose_rate.envir
-  if(class(dose_rate.envir) != "numeric" || length(dose_rate.envir) < 2){
+  if(!inherits(dose_rate.envir, "numeric") || length(dose_rate.envir) < 2){
     stop("[calc_Lamothe2003()] Input for 'dose_rate.envir' is not of type 'numeric' and/or of length < 2!", call. = FALSE)
 
   }else{
@@ -155,7 +190,7 @@ calc_Lamothe2003 <- function(
   }
 
   ##dose_rate.source
-  if(class(dose_rate.source) != "numeric" || length(dose_rate.source) < 2){
+  if(!inherits(dose_rate.source, "numeric") || length(dose_rate.source) < 2){
     stop("[calc_Lamothe2003()] Input for 'dose_rate.source' is not of type 'numeric' and/or of length < 2!", call. = FALSE)
 
   }else{
@@ -173,7 +208,7 @@ calc_Lamothe2003 <- function(
   # Input assignment -----------------------------------------------------------------------------
   ## We allow input as data.frame() and RLum.Results objects ... the output from functions listed
   ## below .. if we allow a data.frame it should have at least Dose, Lx/Tx, Lx/Tx Error
-  if(class(object) == "data.frame"){
+  if(inherits(object, "data.frame")){
     data <- object[,1:3]
 
     ##add signal information
@@ -185,7 +220,7 @@ calc_Lamothe2003 <- function(
 
     }
 
-  }else if(class(object) == "RLum.Results"){
+  }else if(inherits(object, "RLum.Results")){
     if(object@originator == "analyse_SAR.CWOSL" || object@originator == "analyse_pIRIRSequence"){
       ##now we do crazy stuff, we make a self-call here since this file can contain a lot of information
 
