@@ -4,16 +4,16 @@
 
 ##CAUTION NOTE:
 ##(1) Please DO NOT access to the S4 objects by using the slots this causes inconsistent
-## behaviour, please use the correspong RLum-methods instead!
+## behaviour, please use the corresponding RLum-methods instead!
 ##
 ##(2) Especially, please DO NOT include S3-methods for which no S4-method is implemented! Especially
 ##for coercing.
 ##
-##(3) Finally, what ever you want to implemnt, check whether a S4-method exists, it should
+##(3) Finally, what ever you want to implement, check whether a S4-method exists, it should
 ##be just passed to this methods, not the opposite, otherwise this will yield in undesired behaviour
 ##
 ##TODO: For this S3 generics so far no proper documentation exists ... we should consider
-##to provide an overview within a separat document, as it becomes otherwise rather
+##to provide an overview within a separate document, as it becomes otherwise rather
 ##complicated for beginners to work with the documentation.
 ##
 
@@ -33,14 +33,14 @@
 #' has been implemented in the package to increase the usability for users new
 #' in R and who are not familiar with the underlying `RLum`-object structure of
 #' the package. The practical outcome is that operations and functions presented
-#' in standard books on R can be used without knowing the specifica of the R
-#' package 'Luminescence'. For examples see the example section.
+#' in standard books on R can be used without knowing the specifics of the R
+#' package `'Luminescence'`. For examples see the example section.
 #'
 #' @param x [RLum-class] or [Risoe.BINfileData-class] (**required**):
-#' input opject
+#' input object
 #'
 #' @param object [RLum-class] (**required**):
-#' input opject
+#' input object
 #'
 #' @param y [integer] (*optional*):
 #' the row index of the matrix, data.frame
@@ -63,13 +63,13 @@
 #' @param subset `[subset]` [expression] (**required**):
 #' logical expression indicating elements or rows to keep, this function works
 #' in [Risoe.BINfileData-class] objects like [subset.data.frame], but takes care
-#' of the object structure
+#' of the object structure. Works also on [RLum.Analysis-class] objects.
 #'
 #' @param row.names [logical] (*with default*):
 #' enables or disables row names (`as.data.frame`)
 #'
 #' @param recursive [logical] (*with default*):
-#' enables or disables further subsetting (`unlist`)
+#' enables or disables further sub-setting (`unlist`)
 #'
 #' @param optional [logical] (*with default*):
 #' logical. If TRUE, setting row names and converting column names
@@ -367,6 +367,10 @@ as.list.RLum.Results <- function(x, ...) as(x, "list")
 #' @export
 as.list.RLum.Data.Curve <- function(x, ...) as(x, "list")
 
+#' @rdname methods_RLum
+#' @export
+as.list.RLum.Data.Image <- function(x, ...) as(x, "list")
+
 #' @rdname methods_RLum
 #' @export
 as.list.RLum.Analysis <- function(x, ...) as(x, "list")
@@ -381,6 +385,10 @@ as.matrix.RLum.Data.Curve <- function(x, ...) as(x, "matrix")
 #' @rdname methods_RLum
 #' @export
 as.matrix.RLum.Data.Spectrum <- function(x, ...) as(x, "matrix")
+
+#' @rdname methods_RLum
+#' @export
+as.matrix.RLum.Data.Image <- function(x, ...) as(x, "matrix")
 # for RLum.Results ... makes no sense and may yield in unpredictable behaviour
 
 ####################################################################################################
