@@ -1,5 +1,3 @@
-context("calc_MinDose")
-
 data(ExampleData.DeValues, envir = environment())
 temp <- calc_MinDose(data = ExampleData.DeValues$CA1,
                      sigmab = 0.1,
@@ -8,13 +6,16 @@ temp <- calc_MinDose(data = ExampleData.DeValues$CA1,
 
 test_that("check class and length of output", {
   testthat::skip_on_cran()
-  expect_equal(is(temp), c("RLum.Results", "RLum"))
+  local_edition(3)
+
+  expect_s4_class(temp, "RLum.Results")
   expect_equal(length(temp), 9)
 
 })
 
 test_that("check values from output example", {
   testthat::skip_on_cran()
+  local_edition(3)
 
   results <- get_RLum(temp)
 
@@ -24,7 +25,7 @@ test_that("check values from output example", {
   expect_equal(round(results$ci_lower, digits = 5), 29.37526)
   expect_equal(round(results$ci_upper, digits = 5), 39.37503)
   expect_equal(results$par, 3)
-  expect_equal(round(results$sig, digits = 7), 0.7287325)
+  expect_equal(round(results$sig, digits = 2), 2.07)
   expect_equal(round(results$p0, digits = 8), 0.01053938)
   expect_equal(results$mu, NA)
   expect_equal(round(results$Lmax, digits = 5), -43.57969)
